from django.db import models

# Create your models here.
class RtsMap(models.Model):
	name = models.CharField(maxlength=30)
	width = models.SmallIntegerField()
	height = models.SmallIntegerField()
	data = models.TextField()
	class Admin:
		pass
	def __str__(self):
		return self.name

class Player(models.Model):
	name = models.CharField(maxlength=30)
	password = models.CharField(maxlength=30)
	last = models.DateTimeField(auto_now=1)
	class Admin:
		pass

	def __str__(self):
		return self.name

class Game(models.Model):
	name = models.CharField(maxlength=30)
	player = models.ForeignKey(Player,related_name="player")
	admin = models.ForeignKey(Player,related_name="admin")
	winner = models.ForeignKey(Player,related_name="winner")
	started = models.BooleanField()
	RtsMap = models.ForeignKey(RtsMap)
	tick = models.SmallIntegerField()
	class Admin:
		pass

	def __str__(self):
		return self.name

class UnitKind(models.Model):
	name = models.CharField(maxlength=30)
	speed = models.SmallIntegerField()
	health = models.SmallIntegerField()
	class Admin:
		pass

	def __str__(self):
		return self.name

class CombatParameter(models.Model):
	points = models.SmallIntegerField()
	attacker = models.ForeignKey(UnitKind)
	defender = models.ForeignKey(UnitKind,related_name="defender")
	class Admin:
		pass
	def __str__(self):
		return (self.attacker.name +"=>"+self.defender.name)

class Unit(models.Model):
	kind = models.ForeignKey(UnitKind)
	owner = models.ForeignKey(Player)
	game = models.ForeignKey(Game)
	health = models.SmallIntegerField()
	class Admin:
		pass

	def __str__(self):
		return ("["+str(self.id)+"]"+self.game.name+ " " + self.owner.name + " "+self.kind.name)


class UnitHealth(models.Model):
	points = models.SmallIntegerField()
	unit = models.ForeignKey(Unit)
	tick = models.IntegerField()

class UnitPosition(models.Model):
	x = models.SmallIntegerField()
	y = models.SmallIntegerField()
	unit = models.ForeignKey(Unit)
	tick = models.IntegerField()
	class Admin:
		pass

	def __str__(self):
		return (self.unit.__str__()+ " " + str(self.tick))


class Factory(models.Model):
	x = models.SmallIntegerField()
	y = models.SmallIntegerField()
	unitkind = models.ForeignKey(UnitKind)
	rtsmap = models.ForeignKey(RtsMap)
	tickduration = models.SmallIntegerField()
	class Admin:
		pass

	def __str__(self):
		return (self.rtsmap.name + " @ "+self.unitkind.name+" @ "+str(self.x)+"/"+str(self.y))

class FactoryActivation(models.Model):
	tick = models.SmallIntegerField()
	factory = models.ForeignKey(Factory)
	game = models.ForeignKey(Game)
	player = models.ForeignKey(Player)

	class Admin:
		pass

class Attack(models.Model):
	attacker = models.ForeignKey(Unit,related_name="attacker")
	target = models.ForeignKey(Unit,related_name="target")
	game = models.ForeignKey(Game)
	attackpoints = models.SmallIntegerField()

class Chat(models.Model):
	player = models.ForeignKey(Player)
	text = models.CharField(maxlength=200)
	timestamp = models.DateTimeField(auto_now_add=1)
	class Admin:
		pass
